@@ -348,17 +348,14 @@ class Sound(Base):
         # Check the file exists
         sound_file = str(sound_file)
         if not path.isfile(sound_file):
-            raise IOError('sound file "{0}" does not exist'.format(sound_file))
+            raise IOError(f'sound file "{sound_file}" does not exist')
 
         # Load the sound
         try:
             # noinspection PyTypeChecker
             sound_data = mixer.Sound(file=sound_file)
         except pygame_error:
-            warn(
-                'the sound file "{0}" could not be loaded, it has been disabled'
-                ''.format(sound_file)
-            )
+            warn(f'the sound file "{sound_file}" could not be loaded, it has been disabled')
             self._sound[sound_type] = {}
             return False
 
