@@ -143,8 +143,8 @@ class Label(Widget):
         super(Label, self).set_title(title)
         if self._title_generator is not None:
             warn(
-                '{0} title generator is not None, thus, the new title "{1}" will be '
-                'overridden after next update'.format(self.get_class_id(), title)
+                f'{self.get_class_id()} title generator is not None, thus, the new'
+                f' title "{title}" will be overridden after next update'
             )
         return self
 
@@ -180,8 +180,7 @@ class Label(Widget):
         if self._title_generator is not None:
             gen_title = self._title_generator()
             assert isinstance(gen_title, str), \
-                'object generated by the title generator ({0}) is not string-type' \
-                ''.format(gen_title)
+                f'object generated by the title generator ({gen_title}) is not string-type'
             self._title = gen_title
             self._render()
         self.apply_update_callbacks(events)
