@@ -78,8 +78,8 @@ def check_selector_items(items: Union[Tuple, List]) -> None:
             'length of each item on item list must be equal or greater than 1 ' \
             '(i.e. cannot be empty)'
         assert isinstance(e[0], (str, bytes)), \
-            'first element of each item on list must be a string ' \
-            '(the title of each item), but received "{0}"'.format(e[0])
+            f'first element of each item on list must be a string ' \
+            f'(the title of each item), but received "{e[0]}"'
 
 
 # noinspection PyMissingOrEmptyDocstring
@@ -428,7 +428,7 @@ class Selector(Widget):
                     found = True
                     break
             if not found:
-                raise ValueError('no value "{}" found in selector'.format(item))
+                raise ValueError(f'no value "{item}" found in selector')
         elif isinstance(item, int):
             assert 0 <= item < len(self._items), \
                 'item index must be greater than zero and lower than the number ' \
